@@ -10,5 +10,5 @@ test_that("Malformed Nexus File should not work.", {
     }
     badFile <- file.path(pth, "badnex.nex")
     stopifnot(file.exists(badFile))
-    expect_error(make_phylo(file=badFile))
+    expect_error(read_nexus_phylo(file=badFile))
 })
